function [t, y] = euler(dydt, tspan, y0, Nsteps)
% Function to solve a single first-order ODE by Euler's method
% INPUTS:  dydt - handle to a function f(t,y) that calculate dy/dt
%          tspan - 1x2 vector containing the starting and
%                  finishing values of t
%          y0 - initial value of y
%          Nsteps - number of steps of Euler's method to use
% OUTPUTS: t - vector of equally spaced t values
%          y - vector of corresponding y values
dt = (tspan(2)-tspan(1))/Nsteps;
t = (tspan(1):dt:tspan(2))';   % vector of equally spaced t values
y = zeros(Nsteps+1, 1);   % set up vector in which to store y values
y(1) = y0;                % store initial condtion in y(1)
% Loop through t values calculating new y value each time:
for I = 1:Nsteps
    y(I+1) = y(I) + dt*dydt(t(I),y(I));
end